##
##  perl-math.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   versions of individual parts
%define       V_perl                         5.22
%define       V_math_gmp                     2.07
%define       V_math_mpfr                    4.39
%define       V_math_bigint                  1.99
%define       V_math_bigint_gmp              1.32
%define       V_math_bigint_constant         1.16
%define       V_math_bigint_fastcalc         0.29
%define       V_math_symbolic                0.604
%define       V_math_algebra_symbols         1.27
%define       V_math_combinatorics           0.09
%define       V_math_calc_units              1.07
%define       V_math_basecnv                 1.14
%define       V_math_interpolate             1.06
%define       V_math_derivative              0.01
%define       V_math_spline                  0.01
%define       V_math_round                   0.07

#   package information
Name:         perl-math
Summary:      Perl Mathematics Modules
URL:          http://www.cpan.org/
Vendor:       Perl Community
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Perl
License:      GPL/Artistic
Version:      %{V_perl}
Release:      20250612

#   package options
%option       with_gmp    no
%option       with_mpfr   no

#   list of sources
Source0:      http://www.cpan.org/authors/id/T/TU/TURNSTEP/Math-GMP-%{V_math_gmp}.tar.gz
Source1:      http://www.cpan.org/authors/id/S/SI/SISYPHUS/Math-MPFR-%{V_math_mpfr}.tar.gz
Source2:      http://www.cpan.org/authors/id/F/FL/FLORA/Math-BigInt-%{V_math_bigint}.tar.gz
Source3:      http://www.cpan.org/authors/id/F/FL/FLORA/Math-BigInt-GMP-%{V_math_bigint_gmp}.tar.gz
Source4:      http://www.cpan.org/modules/by-module/Math/Math-BigInt-Constant-%{V_math_bigint_constant}.tar.gz
Source5:      http://www.cpan.org/authors/id/F/FL/FLORA/Math-BigInt-FastCalc-%{V_math_bigint_fastcalc}.tar.gz
Source6:      http://www.cpan.org/authors/id/S/SM/SMUELLER/Math-Symbolic-%{V_math_symbolic}.tar.gz
Source7:      http://www.cpan.org/authors/id/P/PR/PRBRENAN/Math-Algebra-Symbols-%{V_math_algebra_symbols}.tar.gz
Source8:      http://www.cpan.org/authors/id/A/AL/ALLENDAY/Math-Combinatorics-%{V_math_combinatorics}.tar.gz
Source9:      http://www.cpan.org/authors/id/S/SF/SFINK/Math-Calc-Units-%{V_math_calc_units}.tar.gz
Source10:     http://www.cpan.org/modules/by-module/Math/Math-BaseCnv-%{V_math_basecnv}.tgz
Source11:     http://www.cpan.org/authors/id/B/BZ/BZAJAC/Math-Interpolate-%{V_math_interpolate}.tar.gz
Source12:     http://www.cpan.org/authors/id/J/JA/JARW/Math-Derivative-%{V_math_derivative}.tar.gz
Source13:     http://www.cpan.org/authors/id/J/JA/JARW/Math-Spline-%{V_math_spline}.tar.gz
Source14:     http://www.cpan.org/authors/id/G/GR/GROMMEL/Math-Round-%{V_math_round}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, perl >= %{V_perl}, perl-openpkg >= %{V_perl}-20040126
PreReq:       OpenPKG, openpkg >= 20160101, perl >= %{V_perl}
BuildPreReq:  perl-util, perl-parse
PreReq:       perl-util, perl-parse
%if "%{with_gmp}" == "yes"
BuildPreReq:  gmp
PreReq:       gmp
%endif
%if "%{with_mpfr}" == "yes"
BuildPreReq:  gmp, mpfr
PreReq:       gmp, mpfr
%endif

%description
    Various modules for mathematics with perl
    - Math::GMP (%{V_math_gmp}) [%{with_gmp}]
    - Math::MPFR (%{V_math_mpfr}) [%{with_mpfr}]
    - Math::BigInt (%{V_math_bigint})
    - Math::BigInt::GMP (%{V_math_bigint_gmp}) [%{with_gmp}]
    - Math::BigInt::Constant (%{V_math_bigint_constant})
    - Math::BigInt::FastCalc (%{V_math_bigint_fastcalc})
    - Math::Symbolic (%{V_math_symbolic})
    - Math::Algebra::Symbols (%{V_math_algebra_symbols})
    - Math::Combinatorics (%{V_math_combinatorics})
    - Math::Calc::Units (%{V_math_calc_units})
    - Math::BaseCnv (%{V_math_basecnv})
    - Math::Derivative (%{V_math_derivative})
    - Math::Interpolate (%{V_math_interpolate})
    - Math::Spline (%{V_math_spline})
    - Math::Round (%{V_math_round})

%track
    prog perl-math:Math-GMP = {
        version   = %{V_math_gmp}
        url       = http://www.cpan.org/authors/id/T/TU/TURNSTEP/
        regex     = Math-GMP-(__VER__)\.tar\.gz
    }
    prog perl-math:Math-MPFR = {
        version   = %{V_math_mpfr}
        url       = http://www.cpan.org/authors/id/S/SI/SISYPHUS/
        regex     = Math-MPFR-(__VER__)\.tar\.gz
    }
    prog perl-math:Math-BigInt = {
        version   = %{V_math_bigint}
        url       = http://www.cpan.org/authors/id/F/FL/FLORA/
        regex     = Math-BigInt-(__VER__)\.tar\.gz
    }
    prog perl-math:Math-BigInt-GMP = {
        version   = %{V_math_bigint_gmp}
        url       = http://www.cpan.org/authors/id/F/FL/FLORA/
        regex     = Math-BigInt-GMP-(__VER__)\.tar\.gz
    }
    prog perl-math:Math-BigInt-Constant = {
        version   = %{V_math_bigint_constant}
        url       = http://www.cpan.org/modules/by-module/Math/
        regex     = Math-BigInt-Constant-(__VER__)\.tar\.gz
    }
    prog perl-math:Math-BigInt-FastCalc = {
        version   = %{V_math_bigint_fastcalc}
        url       = http://www.cpan.org/authors/id/F/FL/FLORA/
        regex     = Math-BigInt-FastCalc-(__VER__)\.tar\.gz
    }
    prog perl-math:Math-Symbolic = {
        version   = %{V_math_symbolic}
        url       = http://www.cpan.org/authors/id/S/SM/SMUELLER/
        regex     = Math-Symbolic-(__VER__)\.tar\.gz
    }
    prog perl-math:Math-Algebra-Symbols = {
        version   = %{V_math_algebra_symbols}
        url       = http://www.cpan.org/authors/id/P/PR/PRBRENAN/
        regex     = Math-Algebra-Symbols-(__VER__)\.tar\.gz
    }
    prog perl-math:Math-Combinatorics = {
        version   = %{V_math_combinatorics}
        url       = http://www.cpan.org/authors/id/A/AL/ALLENDAY/
        regex     = Math-Combinatorics-(__VER__)\.tar\.gz
    }
    prog perl-math:Math-Calc-Units = {
        version   = %{V_math_calc_units}
        url       = http://www.cpan.org/authors/id/S/SF/SFINK/
        regex     = Math-Calc-Units-(__VER__)\.tar\.gz
    }
    prog perl-math:Math-BaseCnv = {
        version   = %{V_math_basecnv}
        url       = http://www.cpan.org/modules/by-module/Math/
        regex     = Math-BaseCnv-(__VER__[^.]*)\.tgz
    }
    prog perl-math:Math-Interpolate = {
        version   = %{V_math_interpolate}
        url       = http://www.cpan.org/authors/id/B/BZ/BZAJAC/
        regex     = Math-Interpolate-(__VER__)\.tar\.gz
    }
    prog perl-math:Math-Derivative = {
        version   = %{V_math_derivative}
        url       = http://www.cpan.org/authors/id/J/JA/JARW/
        regex     = Math-Derivative-(__VER__)\.tar\.gz
    }
    prog perl-math:Math-Spline = {
        version   = %{V_math_spline}
        url       = http://www.cpan.org/authors/id/J/JA/JARW/
        regex     = Math-Spline-(__VER__)\.tar\.gz
    }
    prog perl-math:Math-Round = {
        version   = %{V_math_round}
        url       = http://www.cpan.org/authors/id/G/GR/GROMMEL/
        regex     = Math-Round-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -c
    %setup -q -T -D -a 1
    %setup -q -T -D -a 2
    %setup -q -T -D -a 3
    %setup -q -T -D -a 4
    %setup -q -T -D -a 5
    %setup -q -T -D -a 6
    %setup -q -T -D -a 7
    %setup -q -T -D -a 8
    %setup -q -T -D -a 9
    %setup -q -T -D -a 10
    %setup -q -T -D -a 11
    %setup -q -T -D -a 12
    %setup -q -T -D -a 13
    %setup -q -T -D -a 14

%build

%install
    rm -f Math-BigInt-Constant-*/Build.PL
    %{l_prefix}/bin/perl-openpkg prepare
%if "%{with_gmp}" == "yes"
    %{l_prefix}/bin/perl-openpkg -d %{SOURCE0} \
        -A 'INC="%{l_cppflags}"' \
        -A 'LIBS="%{l_ldflags} -lgmp"' \
        configure build install
%endif
%if "%{with_mpfr}" == "yes"
    %{l_prefix}/bin/perl-openpkg -d %{SOURCE1} \
        -A 'INC="%{l_cppflags}"' \
        -A 'LIBS="%{l_ldflags} -lmpfr -lgmp"' \
        configure build install
%endif
    %{l_prefix}/bin/perl-openpkg -d %{SOURCE2} configure build install
%if "%{with_gmp}" == "yes"
    %{l_prefix}/bin/perl-openpkg -d %{SOURCE3} \
        -A 'INC="%{l_cppflags}"' \
        -A 'LIBS="%{l_ldflags} -lgmp"' \
        configure build install
%endif
    %{l_prefix}/bin/perl-openpkg -d %{SOURCE4}  configure build install
    %{l_prefix}/bin/perl-openpkg -d %{SOURCE5}  configure build install
    %{l_prefix}/bin/perl-openpkg -d %{SOURCE6}  configure build install
    %{l_prefix}/bin/perl-openpkg -d %{SOURCE7}  configure build install
    %{l_prefix}/bin/perl-openpkg -d %{SOURCE8}  configure build install
    %{l_prefix}/bin/perl-openpkg -d %{SOURCE9}  configure build install
    %{l_prefix}/bin/perl-openpkg -d %{SOURCE10} configure build install
    %{l_prefix}/bin/perl-openpkg -d %{SOURCE11} configure build install
    %{l_prefix}/bin/perl-openpkg -d %{SOURCE12} configure build install
    %{l_prefix}/bin/perl-openpkg -d %{SOURCE13} configure build install
    %{l_prefix}/bin/perl-openpkg -d %{SOURCE14} configure build install
    %{l_prefix}/bin/perl-openpkg -F perl-openpkg-files fixate cleanup
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std} `cat perl-openpkg-files`

%files -f files

%clean

